pub struct DecodingKey { /* private fields */ }Expand description
All the different kind of keys we can use to decode a JWT. This key can be re-used so make sure you only initialize it once if you can for better performance.
Implementations
Sourceimpl DecodingKey
impl DecodingKey
Sourcepub fn from_secret(secret: &[u8]) -> DecodingKey
pub fn from_secret(secret: &[u8]) -> DecodingKey
If you’re using HMAC, use this.
Sourcepub fn from_base64_secret(secret: &str) -> Result<DecodingKey, Error>
pub fn from_base64_secret(secret: &str) -> Result<DecodingKey, Error>
If you’re using HMAC with a base64 encoded secret, use this.
Sourcepub fn from_rsa_pem(key: &[u8]) -> Result<DecodingKey, Error>
pub fn from_rsa_pem(key: &[u8]) -> Result<DecodingKey, Error>
If you are loading a public RSA key in a PEM format, use this.
Only exists if the feature use_pem is enabled.
Sourcepub fn from_rsa_components(
modulus: &str,
exponent: &str,
) -> Result<DecodingKey, Error>
pub fn from_rsa_components( modulus: &str, exponent: &str, ) -> Result<DecodingKey, Error>
If you have (n, e) RSA public key components as strings, use this.
Sourcepub fn from_rsa_raw_components(modulus: &[u8], exponent: &[u8]) -> DecodingKey
pub fn from_rsa_raw_components(modulus: &[u8], exponent: &[u8]) -> DecodingKey
If you have (n, e) RSA public key components already decoded, use this.
Sourcepub fn from_ec_pem(key: &[u8]) -> Result<DecodingKey, Error>
pub fn from_ec_pem(key: &[u8]) -> Result<DecodingKey, Error>
If you have a ECDSA public key in PEM format, use this.
Only exists if the feature use_pem is enabled.
Sourcepub fn from_ec_components(x: &str, y: &str) -> Result<DecodingKey, Error>
pub fn from_ec_components(x: &str, y: &str) -> Result<DecodingKey, Error>
If you have (x,y) ECDSA key components
Sourcepub fn from_ed_pem(key: &[u8]) -> Result<DecodingKey, Error>
pub fn from_ed_pem(key: &[u8]) -> Result<DecodingKey, Error>
If you have a EdDSA public key in PEM format, use this.
Only exists if the feature use_pem is enabled.
Sourcepub fn from_rsa_der(der: &[u8]) -> DecodingKey
pub fn from_rsa_der(der: &[u8]) -> DecodingKey
If you know what you’re doing and have a RSA DER encoded public key, use this.
Sourcepub fn from_ec_der(der: &[u8]) -> DecodingKey
pub fn from_ec_der(der: &[u8]) -> DecodingKey
If you know what you’re doing and have a RSA EC encoded public key, use this.
Sourcepub fn from_ed_der(der: &[u8]) -> DecodingKey
pub fn from_ed_der(der: &[u8]) -> DecodingKey
If you know what you’re doing and have a Ed DER encoded public key, use this.
Sourcepub fn from_ed_components(x: &str) -> Result<DecodingKey, Error>
pub fn from_ed_components(x: &str) -> Result<DecodingKey, Error>
From x part (base64 encoded) of the JWK encoding