pub struct MeteredReceiver<T> { /* private fields */ }Expand description
Wraps the receiving end of a channel with a gauge for tracking the size of the channel. We subtract the size of the channel from the gauge on drop to avoid leaking the metric.
Implementations
Sourceimpl<T> MeteredReceiver<T>
impl<T> MeteredReceiver<T>
pub fn new(inner: Receiver<T>) -> Self
pub fn with_gauge(inner: Receiver<T>, gauge: IntGauge) -> Self
pub async fn recv(&mut self) -> Option<T>
pub async fn recv_many(&mut self, buf: &mut Vec<T>, max: usize) -> usize
pub fn poll_recv(&mut self, cx: &mut Context<'_>) -> Poll<Option<T>>
pub fn poll_recv_many( &mut self, cx: &mut Context<'_>, buf: &mut Vec<T>, max: usize, ) -> Poll<usize>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn close(&mut self)