pub struct MetadataFile {
pub version: Version,
pub edition: String,
pub client_connection_id: Option<ConnectionId>,
}Fields
version: Versionedition: Stringclient_connection_id: Option<ConnectionId>Unused and always None in SpacetimeDB-standalone,
but used by SpacetimeDB-cloud.
Implementations
Sourceimpl MetadataFile
impl MetadataFile
pub fn new(edition: &str) -> Self
pub fn read(path: &MetadataTomlPath) -> Result<Option<Self>>
pub fn write(&self, path: &MetadataTomlPath) -> Result<()>
Sourcepub fn check_compatibility_and_update(self, current: Self) -> Result<Self>
pub fn check_compatibility_and_update(self, current: Self) -> Result<Self>
Check if this meta file is compatible with the default meta file of a just-started database, and if so return the metadata to write back to the file.
self is the metadata file read from a database, and current is
the default metadata file that the active database version would
right to a new database.