pub struct ChunkPool { /* private fields */ }Expand description
A pool of available unused chunks.
The number of chunks stored in a ChunkPool is limited by [MAX_CHUNKS_IN_POOL],
and the size of each individual saved chunk is limited by [MAX_CHUNK_SIZE_IN_BYTES].
Implementations
Sourceimpl ChunkPool
impl ChunkPool
Sourcepub fn put(&mut self, chunk: Vec<u8>)
pub fn put(&mut self, chunk: Vec<u8>)
Return a chunk back to the pool, or frees it, as appropriate.
chunk will be freed if either:
selfalready contains at least [MAX_CHUNKS_IN_POOL] chunks, orchunk.capacity()is greater than [MAX_CHUNK_SIZE_IN_BYTES].
These limits place an upper bound on the memory usage of a single ChunkPool.