ModuleHost

Struct ModuleHost 

pub struct ModuleHost {
    pub info: Arc<ModuleInfo>,
    /* private fields */
}

Fields

info: Arc<ModuleInfo>

Implementations

Source

impl ModuleHost

pub fn info(&self) -> &ModuleInfo

pub fn subscriptions(&self) -> &ModuleSubscriptions

pub async fn on_module_thread<F, R>( &self, label: &str, f: F, ) -> Result<R, Error>
where F: FnOnce() -> R + Send + 'static, R: Send + 'static,

Run a function on the JobThread for this module. This would deadlock if it is called within another call to on_module_thread. Since this is async, and f is sync, deadlocking shouldn’t be a problem.

pub async fn disconnect_client(&self, client_id: ClientActorId)

pub async fn call_identity_connected( &self, caller_identity: Identity, caller_connection_id: ConnectionId, ) -> Result<(), ClientConnectedError>

Invoke the module’s client_connected reducer, if it has one, and insert a new row into st_client for (caller_identity, caller_connection_id).

The host inspects st_client when restarting in order to run client_disconnected reducers for clients that were connected at the time when the host went down. This ensures that every client connection eventually has client_disconnected invoked.

If this method returns Ok, then the client connection has been approved, and the new row has been inserted into st_client.

If this method returns Err, then the client connection has either failed or been rejected, and st_client has not been modified. In this case, the caller should terminate the connection.

pub fn call_identity_disconnected_inner( &self, caller_identity: Identity, caller_connection_id: ConnectionId, inst: &mut dyn ModuleInstance, ) -> Result<(), ReducerCallError>

pub async fn call_identity_disconnected( &self, caller_identity: Identity, caller_connection_id: ConnectionId, ) -> Result<(), ReducerCallError>

Invoke the module’s client_disconnected reducer, if it has one, and delete the client’s row from st_client, if any.

The host inspects st_client when restarting in order to run client_disconnected reducers for clients that were connected at the time when the host went down. This ensures that every client connection eventually has client_disconnected invoked.

Unlike Self::call_identity_connected, this method swallows errors returned by the client_disconnected reducer. The database can’t reject a disconnection - the client’s gone, whether the database likes it or not.

If this method returns an error, the database is likely to wind up in a bad state, as that means we’ve somehow failed to delete from st_client. We cannot meaningfully handle this. Sometimes it just means that the database no longer exists, though, which is fine.

pub async fn call_reducer( &self, caller_identity: Identity, caller_connection_id: Option<ConnectionId>, client: Option<Arc<ClientConnectionSender>>, request_id: Option<RequestId>, timer: Option<Instant>, reducer_name: &str, args: ReducerArgs, ) -> Result<ReducerCallResult, ReducerCallError>

pub async fn call_scheduled_reducer( &self, call_reducer_params: impl FnOnce(&MutTxId) -> Result<Option<CallReducerParams>> + Send + 'static, ) -> Result<ReducerCallResult, ReducerCallError>

pub fn subscribe_to_logs(&self) -> Result<Receiver<Bytes>>

pub async fn init_database( &self, program: Program, ) -> Result<Option<ReducerCallResult>, InitDatabaseError>

pub async fn update_database( &self, program: Program, old_module_info: Arc<ModuleInfo>, ) -> Result<UpdateDatabaseResult, Error>

pub async fn exit(&self)

pub async fn exited(&self)

pub fn inject_logs(&self, log_level: LogLevel, message: &str)

pub async fn one_off_query<F: WebsocketFormat>( &self, caller_identity: Identity, query: String, client: Arc<ClientConnectionSender>, message_id: Vec<u8>, timer: Instant, into_message: impl FnOnce(OneOffQueryResponseMessage<F>) -> SerializableMessage + Send + 'static, ) -> Result<(), Error>

Execute a one-off query and send the results to the given client. This only returns an error if there is a db-level problem. An error with the query itself will be sent to the client.

pub fn clear_table(&self, table_name: &str) -> Result<(), Error>

FIXME(jgilles): this is a temporary workaround for deleting not currently being supported for tables without primary keys. It is only used in the benchmarks. Note: this doesn’t drop the table, it just clears it!

pub fn downgrade(&self) -> WeakModuleHost

pub fn database_info(&self) -> &Database