pub struct Database {
pub id: u64,
pub database_identity: Identity,
pub owner_identity: Identity,
pub host_type: HostType,
pub initial_program: Hash,
}Expand description
Description of a database.
Fields
id: u64Internal id of the database, assigned by the control database.
database_identity: IdentityPublic identity (i.e. Identity) of the database.
owner_identity: IdentityIdentity of the database’s owner.
host_type: HostTypeHostType of the module associated with the database.
Valid only for as long as initial_program is valid.
initial_program: Hash[Hash] of the compiled module to initialize the database with.
Updating the database’s module will not change this value.