CallReducer

Struct CallReducer 

pub struct CallReducer<Args> {
    pub reducer: Box<str>,
    pub args: Args,
    pub request_id: u32,
    pub flags: CallReducerFlags,
}
Request a reducer run.

Parametric over the argument type to enable ClientMessage::map_args.

Fields

reducer: Box<str>

The name of the reducer to call.

args: Args

The arguments to the reducer.

In the wire format, this will be a Bytes, BSATN or JSON encoded according to the reducer’s argument schema and the enclosing message format.

request_id: u32

An identifier for a client request.

The server will include the same ID in the response TransactionUpdate.

flags: CallReducerFlags

Assorted flags that can be passed when calling a reducer.

Currently accepts 0 or 1 where the latter means that the caller does not want to be notified about the reducer without being subscribed to any relevant queries.