pub struct InitialSubscription<F>where
F: WebsocketFormat,{
pub database_update: DatabaseUpdate<F>,
pub request_id: u32,
pub total_host_execution_duration: TimeDuration,
}Expand description
Response to Subscribe containing the initial matching rows.
Fields
database_update: DatabaseUpdate<F>A DatabaseUpdate containing only inserts, the rows which match the subscription queries.
request_id: u32An identifier sent by the client in requests. The server will include the same request_id in the response.
total_host_execution_duration: TimeDurationThe overall time between the server receiving a request and sending the response.