pub struct QueryUpdate<F>where
F: WebsocketFormat,{
pub deletes: <F as WebsocketFormat>::List,
pub inserts: <F as WebsocketFormat>::List,
}Fields
deletes: <F as WebsocketFormat>::ListWhen in a TransactionUpdate, the matching rows of this table deleted by the transaction.
Rows are encoded as BSATN or JSON according to the table’s schema and the client’s requested protocol.
Always empty when in an InitialSubscription.
inserts: <F as WebsocketFormat>::ListWhen in a TransactionUpdate, the matching rows of this table inserted by the transaction.
When in an InitialSubscription, the matching rows of this table in the entire committed state.
Rows are encoded as BSATN or JSON according to the table’s schema and the client’s requested protocol.