ReducerCallInfo

Struct ReducerCallInfo 

pub struct ReducerCallInfo<F>
where F: WebsocketFormat,
{ pub reducer_name: Box<str>, pub reducer_id: u32, pub args: <F as WebsocketFormat>::Single, pub request_id: u32, }
Contained in a TransactionUpdate, metadata about a reducer invocation.

Fields

reducer_name: Box<str>

The name of the reducer that was called.

NOTE(centril, 1.0): For bandwidth resource constrained clients this can encourage them to have poor naming of reducers like a. We should consider not sending this at all and instead having a startup message where the name <-> id bindings are established between the host and the client.

reducer_id: u32

The numerical id of the reducer that was called.

args: <F as WebsocketFormat>::Single

The arguments to the reducer, encoded as BSATN or JSON according to the reducer’s argument schema and the client’s requested protocol.

request_id: u32

An identifier for a client request