SubscribeMulti

Struct SubscribeMulti 

pub struct SubscribeMulti {
    pub query_strings: Box<[Box<str>]>,
    pub request_id: u32,
    pub query_id: QueryId,
}

Fields

query_strings: Box<[Box<str>]>

A single SQL SELECT query to subscribe to.

request_id: u32

An identifier for a client request.

query_id: QueryId

An identifier for this subscription, which should not be used for any other subscriptions on the same connection. This is used to refer to this subscription in Unsubscribe messages from the client and errors sent from the server. These only have meaning given a ConnectionId.