pub struct SubscribeMultiApplied<F>where
F: WebsocketFormat,{
pub request_id: u32,
pub total_host_execution_duration_micros: u64,
pub query_id: QueryId,
pub update: DatabaseUpdate<F>,
}Expand description
Response to Subscribe containing the initial matching rows.
Fields
request_id: u32The request_id of the corresponding SubscribeSingle message.
total_host_execution_duration_micros: u64The overall time between the server receiving a request and sending the response.
query_id: QueryIdAn identifier for the subscribed query sent by the client.
update: DatabaseUpdate<F>The matching rows for this query.