pub struct CoreReservations {
pub databases: f64,
pub tokio_workers: f64,
pub rayon: f64,
pub irq: usize,
pub reserved: usize,
}Expand description
The desired distribution of available cores to purposes.
Note that, in addition to reserved, Cores reserves two additional
cores for the operating system. That is, the denominator for fractions
given below is num_cpus - reserved - 2.
Fields
databases: f64Cores to run database instances on.
Default: 1/8
tokio_workers: f64Cores to run tokio worker threads on.
Default: 4/8
rayon: f64Cores to run rayon threads on.
Default: 1/8
irq: usizeCores to reserve for IRQ handling.
This will be the first n CoreIds in the list.
Only make use of this if you’re configuring the machine for IRQ pinning!
Default: 2
reserved: usizeExtra reserved cores.
If greater than zero, this many cores will be reserved before any of the other reservations are made (but after reserving the OS cores).
Default: 0
Implementations