JwtClaims

Struct JwtClaims 

#[non_exhaustive]
pub struct JwtClaims { /* private fields */ }
The JWT of an AuthCtx.

Implementations

Source

impl JwtClaims

pub fn subject(&self) -> &str

Returns the tokens subject, from the sub claim.

pub fn issuer(&self) -> &str

Returns the issuer for these credentials, from the iss claim.

pub fn audience(&self) -> &[String]

Returns the audience for these credentials, from the aud claim.

pub fn identity(&self) -> Identity

Returns the identity for these credentials, which is based on the iss and sub claims.

pub fn raw_payload(&self) -> &str

Get the whole JWT payload as a json string.

This method is intended for parsing custom claims, beyond the methods offered by JwtClaims.