PointIndex

Struct PointIndex 

pub struct PointIndex<Tbl: Table, IndexType, Idx: Index> { /* private fields */ }
A handle to a Hash index on a table.

To get one of these from a ReducerContext, use:

ctx.db.{table}().{index}()

for a table table and an index index.

Example:

use spacetimedb::{table, DbContext, PointIndex, ReducerContext};

#[table(accessor = user,
    index(accessor = dogs_and_name, hash(columns = [dogs, name])))]
struct User {
    id: u32,
    name: String,
    /// Number of dogs owned by the user.
    dogs: u64
}

fn demo(ctx: &ReducerContext) {
    let by_dogs_and_name: PointIndex<_, (u64, String), _> = ctx.db.user().dogs_and_name();
}

For single-column indexes, use the name of the column:

use spacetimedb::{table, DbContext, RangedIndex, ReducerContext};

#[table(accessor = user)]
struct User {
    id: u32,
    username: String,
    #[index(btree)]
    dogs: u64
}

fn demo(ctx: &ReducerContext) {
    let by_dogs: RangedIndex<_, (u64,), _> = ctx.db().user().dogs();
}

Implementations

Source

impl<Tbl: Table, IndexType, Idx: IndexIsPointed> PointIndex<Tbl, IndexType, Idx>

pub fn filter<P, K>( &self, point: P, ) -> impl Iterator<Item = Tbl::Row> + use<P, K, Tbl, IndexType, Idx>
where P: WithPointArg<K>,

Returns an iterator over all rows in the database state where the indexed column(s) equal point.

Unlike for ranged indices, this method only accepts a point and not any prefix or range.

For example:

use spacetimedb::{table, ReducerContext, PointIndex};

#[table(accessor = user,
    index(accessor = dogs_and_name, hash(columns = [dogs, name])))]
struct User {
    id: u32,
    name: String,
    dogs: u64
}

fn demo(ctx: &ReducerContext) {
    let by_dogs_and_name: PointIndex<_, (u64, String), _> = ctx.db.user().dogs_and_name();

    // Find user with exactly 25 dogs and exactly the name "Joseph".
    for user in by_dogs_and_name.filter((25u64, "Joseph")) {
        /* ... */
    }

    // You can also pass arguments by reference if desired.
    for user in by_dogs_and_name.filter((&25u64, &"Joseph".to_string())) {
        /* ... */
    }
}
pub fn delete<P, K>(&self, point: P) -> u64
where P: WithPointArg<K>,

Deletes all rows in the database state where the indexed column(s) equal point.

Unlike for ranged indices, this method only accepts a point and not any prefix or range.

For example:

use spacetimedb::{table, ReducerContext, PointIndex};

#[table(accessor = user,
    index(accessor = dogs_and_name, hash(columns = [dogs, name])))]
struct User {
    id: u32,
    name: String,
    dogs: u64
}

fn demo(ctx: &ReducerContext) {
    let by_dogs_and_name: PointIndex<_, (u64, String), _> = ctx.db.user().dogs_and_name();

    // Delete users with exactly 25 dogs, and exactly the name "Joseph".
    by_dogs_and_name.delete((25u64, "Joseph"));

    // You can also pass arguments by reference if desired.
    by_dogs_and_name.delete((&25u64, &"Joseph".to_string()));
}

May panic if deleting any one of the rows would violate a constraint, though at present no such constraints exist.