pub struct ViewContext {
pub db: LocalReadOnly,
pub from: QueryBuilder,
/* private fields */
}Expand description
One of two possible types that can be passed as the first argument to a #[view].
The other is AnonymousViewContext.
Use this type if the view depends on the caller’s identity.
Fields
db: LocalReadOnlyfrom: QueryBuilderImplementations
Sourceimpl ViewContext
impl ViewContext
pub fn new(sender: Identity) -> Self
Sourcepub fn as_anonymous(&self) -> AnonymousViewContext
pub fn as_anonymous(&self) -> AnonymousViewContext
Obtain an AnonymousViewContext by dropping sender.