Module execution_unit

Module execution_unit 

Structs

ExecutionUnit
An atomic unit of execution within a subscription set. Currently just a single query plan, however in the future this could be multiple query plans, such as those of an incremental join.
QueryHash
A hash for uniquely identifying query execution units, to avoid recompilation of queries that have an open subscription.