ExecutionUnit

Struct ExecutionUnit 

pub struct ExecutionUnit { /* private fields */ }
An atomic unit of execution within a subscription set. Currently just a single query plan, however in the future this could be multiple query plans, such as those of an incremental join.

Implementations

Source

impl ExecutionUnit

pub fn new(eval_plan: SupportedQuery, hash: QueryHash) -> Result<Self, DBError>

pub fn kind(&self) -> Supported

Is this a single table select or a semijoin?

pub fn hash(&self) -> QueryHash

The unique query hash for this execution unit.

pub fn return_table(&self) -> TableId

The table from which this query returns rows.

pub fn return_name(&self) -> Box<str>

pub fn filter_table(&self) -> TableId

The table on which this query filters rows. In the case of a single table select, this is the same as the return table. In the case of a semijoin, it is the auxiliary table against which we are joining.

pub fn eval<F: WebsocketFormat>( &self, db: &RelationalDB, tx: &Tx, sql: &str, slow_query_threshold: Option<Duration>, compression: Compression, ) -> Option<TableUpdate<F>>

Evaluate this execution unit against the database using the specified format.

pub fn eval_incr<'a>( &'a self, db: &'a RelationalDB, tx: &'a TxMode<'a>, sql: &'a str, tables: impl 'a + Clone + Iterator<Item = &'a DatabaseTableUpdate>, slow_query_threshold: Option<Duration>, ) -> Option<DatabaseTableUpdateRelValue<'a>>

Evaluate this execution unit against the given delta tables.

pub fn row_estimate(&self, tx: &TxId) -> u64

The estimated number of rows returned by this execution unit.