pub struct Plan { /* private fields */ }Implementations
Sourceimpl Plan
impl Plan
Sourcepub fn new(plans: Vec<SubscriptionPlan>, hash: QueryHash, text: String) -> Self
pub fn new(plans: Vec<SubscriptionPlan>, hash: QueryHash, text: String) -> Self
Create a new subscription plan to be cached
Sourcepub fn subscribed_table_id(&self) -> TableId
pub fn subscribed_table_id(&self) -> TableId
A subscription query return rows from a single table. This method returns the id of that table.
Sourcepub fn subscribed_table_name(&self) -> &str
pub fn subscribed_table_name(&self) -> &str
A subscription query return rows from a single table. This method returns the name of that table.
Sourcepub fn index_ids(&self) -> impl Iterator<Item = (TableId, IndexId)>
pub fn index_ids(&self) -> impl Iterator<Item = (TableId, IndexId)>
Returns the index ids from which this subscription reads
Sourcepub fn table_ids(&self) -> impl Iterator<Item = TableId> + '_
pub fn table_ids(&self) -> impl Iterator<Item = TableId> + '_
Returns the table ids from which this subscription reads
Sourcepub fn plans_fragments(&self) -> impl Iterator<Item = &SubscriptionPlan> + '_
pub fn plans_fragments(&self) -> impl Iterator<Item = &SubscriptionPlan> + '_
Returns the plan fragments that comprise this subscription. Will only return one element unless there is a table with multiple RLS rules.
Sourcepub fn join_edges(
&self,
) -> impl Iterator<Item = (JoinEdge, AlgebraicValue)> + '_
pub fn join_edges( &self, ) -> impl Iterator<Item = (JoinEdge, AlgebraicValue)> + '_
Returns the join edges for this plan, if any.