pub struct SearchArguments { /* private fields */ }Expand description
In this container, we keep track of parameterized subscription queries. This is used to prune unnecessary queries during subscription evaluation.
TODO: This container is populated on initial subscription. Ideally this information would be stored in the datastore, but because subscriptions are evaluated using a read only tx, we have to manage this memory separately.
If we stored this information in the datastore, we could encode pruning logic in the execution plan itself.