pub enum CallReducerFlags {
FullUpdate,
NoSuccessNotify,
}Variants
FullUpdate
The reducer’s caller does want to be notified about the reducer completing successfully regardless of whether the caller had subscribed to a relevant query.
Note that updates to a reducer’s caller are always sent as full updates whether subscribed to a relevant query or not. That is, the light tx mode setting does not apply to the reducer’s caller.
This is the default flag.
NoSuccessNotify
The reducer’s caller does not want to be notified about the reducer completing successfully without having subscribed to any of the relevant queries.