pub enum CompressableQueryUpdate<F>where
F: WebsocketFormat,{
Uncompressed(QueryUpdate<F>),
Brotli(Bytes),
Gzip(Bytes),
}Variants
Implementations
Sourceimpl<F> CompressableQueryUpdate<F>where
F: WebsocketFormat,
impl<F> CompressableQueryUpdate<F>where
F: WebsocketFormat,
Sourcepub fn is_uncompressed(&self) -> bool
pub fn is_uncompressed(&self) -> bool
Returns true if this is a CompressableQueryUpdate::Uncompressed, otherwise false
Sourcepub fn as_uncompressed_mut(&mut self) -> Option<&mut QueryUpdate<F>>
pub fn as_uncompressed_mut(&mut self) -> Option<&mut QueryUpdate<F>>
Optionally returns mutable references to the inner fields if this is a CompressableQueryUpdate::Uncompressed, otherwise None
Sourcepub fn as_uncompressed(&self) -> Option<&QueryUpdate<F>>
pub fn as_uncompressed(&self) -> Option<&QueryUpdate<F>>
Optionally returns references to the inner fields if this is a CompressableQueryUpdate::Uncompressed, otherwise None
Sourcepub fn into_uncompressed(
self,
) -> Result<QueryUpdate<F>, CompressableQueryUpdate<F>>
pub fn into_uncompressed( self, ) -> Result<QueryUpdate<F>, CompressableQueryUpdate<F>>
Returns the inner fields if this is a CompressableQueryUpdate::Uncompressed, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_brotli(&self) -> bool
pub fn is_brotli(&self) -> bool
Returns true if this is a CompressableQueryUpdate::Brotli, otherwise false
Sourcepub fn as_brotli_mut(&mut self) -> Option<&mut Bytes>
pub fn as_brotli_mut(&mut self) -> Option<&mut Bytes>
Optionally returns mutable references to the inner fields if this is a CompressableQueryUpdate::Brotli, otherwise None
Sourcepub fn as_brotli(&self) -> Option<&Bytes>
pub fn as_brotli(&self) -> Option<&Bytes>
Optionally returns references to the inner fields if this is a CompressableQueryUpdate::Brotli, otherwise None
Sourcepub fn into_brotli(self) -> Result<Bytes, CompressableQueryUpdate<F>>
pub fn into_brotli(self) -> Result<Bytes, CompressableQueryUpdate<F>>
Returns the inner fields if this is a CompressableQueryUpdate::Brotli, otherwise returns back the enum in the Err case of the result
Sourcepub fn is_gzip(&self) -> bool
pub fn is_gzip(&self) -> bool
Returns true if this is a CompressableQueryUpdate::Gzip, otherwise false
Sourcepub fn as_gzip_mut(&mut self) -> Option<&mut Bytes>
pub fn as_gzip_mut(&mut self) -> Option<&mut Bytes>
Optionally returns mutable references to the inner fields if this is a CompressableQueryUpdate::Gzip, otherwise None
Sourcepub fn as_gzip(&self) -> Option<&Bytes>
pub fn as_gzip(&self) -> Option<&Bytes>
Optionally returns references to the inner fields if this is a CompressableQueryUpdate::Gzip, otherwise None
Sourcepub fn into_gzip(self) -> Result<Bytes, CompressableQueryUpdate<F>>
pub fn into_gzip(self) -> Result<Bytes, CompressableQueryUpdate<F>>
Returns the inner fields if this is a CompressableQueryUpdate::Gzip, otherwise returns back the enum in the Err case of the result
Sourceimpl CompressableQueryUpdate<BsatnFormat>
impl CompressableQueryUpdate<BsatnFormat>
pub fn maybe_decompress(self) -> QueryUpdate<BsatnFormat>