#[non_exhaustive]pub struct JwtClaims { /* private fields */ }Implementations
Sourceimpl JwtClaims
impl JwtClaims
Sourcepub fn audience(&self) -> &[String]
pub fn audience(&self) -> &[String]
Returns the audience for these credentials, from the aud claim.
Sourcepub fn identity(&self) -> Identity
pub fn identity(&self) -> Identity
Returns the identity for these credentials, which is based on the iss and sub claims.
Sourcepub fn raw_payload(&self) -> &str
pub fn raw_payload(&self) -> &str
Get the whole JWT payload as a json string.
This method is intended for parsing custom claims,
beyond the methods offered by JwtClaims.